==> service-common-2.41.0-20170921.040332-70-sources.jar: com/baijia/tianxiao/util/ListUtil.java <==
package com.baijia.tianxiao.util;

import java.util.*;

import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.BooleanUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class ListUtil {

    private static Logger logger = LoggerFactory.getLogger(ListUtil.class);

    public static <T> List<T> getSubList(List<T> list, int offset, int count) {
        if (offset < 0) {
            offset = 0;
        }
        if (list == null || list.size() - 1 < offset) {
            return new ArrayList<T>();
        }
        int end = (list.size() > offset + count) ? offset + count : list.size();
        return list.subList(offset, end);
    }

    public static <K, V> void insertIntoMap(Map<K, V> map, List<K> keys, V value) {
        if (map != null && keys != null) {
            for (K key : keys) {
                map.put(key, value);
            }
        }
    }

    public static boolean allNull(Object first, Object... objects) {
        if (first != null) {
            return false;
        } else if (ArrayUtils.isEmpty(objects)) {
            return true;
        }
        for (Object o : objects) {
            if (o != null) {
                return false;
            }
        }
        return true;
    }

    public static boolean allNotNull(Object first, Object... objects) {
        if (first == null) {
            return false;
        } else if (ArrayUtils.isEmpty(objects)) {
            return true;
        }
        for (Object o : objects) {
            if (o == null) {
                return false;
            }
        }
        return true;
    }

    public static boolean hasNull(Object first, Object... objects) {
        if (first == null) {
            return true;
        } else if (ArrayUtils.isEmpty(objects)) {
            return false;
        }
        for (Object o : objects) {
            if (o == null) {
                return true;
            }
        }
        return false;
    }

    public static boolean hasNotNull(Object first, Object... objects) {
        if (first != null) {
            return true;
        } else if (ArrayUtils.isEmpty(objects)) {
            return false;
        }
        for (Object o : objects) {
            if (o != null) {
                return true;
            }
        }
        return false;
    }

    public static <T> boolean in(T value, T... list) {
        if (ArrayUtils.isEmpty(list)) {
            return false;
        }
        for (T t : list) {
            if (ObjectUtils.equals(value, t)) {
                return true;
            }
        }
        return false;
    }

    public static <T> boolean notIn(T value, T... list) {
        return !in(value, list);
    }

    public static boolean or(boolean... values) {
        return BooleanUtils.or(values);
    }

    public static boolean and(boolean... values) {
        return BooleanUtils.and(values);
    }

    @SuppressWarnings("unchecked")
    public static <K, V> List<K> toKeyList(Collection<? extends V> list, String field, Class<V> clazz) {
        List<K> retList = new ArrayList<K>();
        if (list != null && list.size() > 0) {
            for (V value : list) {
                retList.add((K) getKey(value, field, clazz));
            }
        }
        return retList;
    }

    @SuppressWarnings("unchecked")
    private static <K, V> K getKey(V value, String field, Class<V> clazz) {
        String method = "get" + field.substring(0, 1).toUpperCase() + field.substring(1);
        K key = null;
        try {
            key = (K) clazz.getMethod(method).invoke(value);
        } catch (Exception e) {
            logger.warn("[Exception]", e);
        }
        return key;
    }

    /**
     * @Description:把数组转换为一个用逗号分隔的字符串 ，以便于用in+String 查询
     */
    public static String converToString(String[] ig) {
        String str = "";
        if (ig != null && ig.length > 0) {
            for (int i = 0; i < ig.length; i++) {
                str += ig[i] + ",";
            }
        }
        str = str.substring(0, str.length() - 1);
        return str;
    }

    /**
     * @Description:把list转换为一个用逗号分隔的字符串
     */
    public static String listToString(List list) {
        StringBuilder sb = new StringBuilder();
        if (list != null && list.size() > 0) {
            for (int i = 0; i < list.size(); i++) {
                if (i < list.size() - 1) {
                    sb.append(list.get(i) + ",");
                } else {
                    sb.append(list.get(i));
                }
            }
        }
        return sb.toString();
    }

    public static int BinSearch(Integer[] data, Integer key) {
        int low = 0;
        int high = data.length - 1;
        int mid = 0;
        if (data[low] == key) {
            return low;
        }
        if (data[high] == key) {
            return high;
        }
        while (low <= high) {
            mid = (low + high) / 2;
            if (data[mid] == key) {
                return mid;
            }
            if (data[mid] > key) {
                high = mid - 1;
            } else {
                low = mid + 1;
            }
        }
        if (low > high) {
            return -1;
        }
        return 0;
    }

    public static List<Long> intListToLong(List<Integer> list) {
        if (CollectionUtils.isEmpty(list)) {
            return Collections.EMPTY_LIST;
        }
        List<Long> result = Lists.newArrayList();
        for (Integer one : list) {
            result.add(one.longValue());
        }
        return result;
    }

    public static void main(String[] args) {
        Integer[] data = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
        System.out.println(BinSearch(data, 3));
        System.out.print(1 << 8);
    }
}

==> service-common-2.43.0-20171026.021638-63-sources.jar: com/baijia/tianxiao/util/ListUtil.java <==
package com.baijia.tianxiao.util;

import java.util.*;

import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.ObjectUtils;
import org.apache.commons.lang3.BooleanUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import lombok.extern.slf4j.Slf4j;

@Slf4j
public class ListUtil {

    private static Logger logger = LoggerFactory.getLogger(ListUtil.class);

    public static <T> List<T> getSubList(List<T> list, int offset, int count) {
        if (offset < 0) {
            offset = 0;
        }
        if (list == null || list.size() - 1 < offset) {
            return new ArrayList<T>();
        }
        int end = (list.size() > offset + count) ? offset + count : list.size();
        return list.subList(offset, end);
    }

    public static <K, V> void insertIntoMap(Map<K, V> map, List<K> keys, V value) {
        if (map != null && keys != null) {
            for (K key : keys) {
                map.put(key, value);
            }
        }
    }

    public static boolean allNull(Object first, Object... objects) {
        if (first != null) {
            return false;
        } else if (ArrayUtils.isEmpty(objects)) {
            return true;
        }
        for (Object o : objects) {
            if (o != null) {
                return false;
            }
        }
        return true;
    }

    public static boolean allNotNull(Object first, Object... objects) {
        if (first == null) {
            return false;
        } else if (ArrayUtils.isEmpty(objects)) {
            return true;
        }
        for (Object o : objects) {
            if (o == null) {
                return false;
            }
        }
        return true;
    }

    public static boolean hasNull(Object first, Object... objects) {
        if (first == null) {
            return true;
        } else if (ArrayUtils.isEmpty(objects)) {
            return false;
        }
        for (Object o : objects) {
            if (o == null) {
                return true;
            }
        }
        return false;
    }

    public static boolean hasNotNull(Object first, Object... objects) {
        if (first != null) {
            return true;
        } else if (ArrayUtils.isEmpty(objects)) {
            return false;
        }
        for (Object o : objects) {
            if (o != null) {
                return true;
            }
        }
        return false;
    }

    public static <T> boolean in(T value, T... list) {
        if (ArrayUtils.isEmpty(list)) {
            return false;
        }
        for (T t : list) {
            if (ObjectUtils.equals(value, t)) {
                return true;
            }
        }
        return false;
    }

    public static <T> boolean notIn(T value, T... list) {
        return !in(value, list);
    }

    public static boolean or(boolean... values) {
        return BooleanUtils.or(values);
    }

    public static boolean and(boolean... values) {
        return BooleanUtils.and(values);
    }

    @SuppressWarnings("unchecked")
    public static <K, V> List<K> toKeyList(Collection<? extends V> list, String field, Class<V> clazz) {
        List<K> retList = new ArrayList<K>();
        if (list != null && list.size() > 0) {
            for (V value : list) {
                retList.add((K) getKey(value, field, clazz));
            }
        }
        return retList;
    }

    @SuppressWarnings("unchecked")
    private static <K, V> K getKey(V value, String field, Class<V> clazz) {
        String method = "get" + field.substring(0, 1).toUpperCase() + field.substring(1);
        K key = null;
        try {
            key = (K) clazz.getMethod(method).invoke(value);
        } catch (Exception e) {
            logger.warn("[Exception]", e);
        }
        return key;
    }

    /**
     * @Description:把数组转换为一个用逗号分隔的字符串 ，以便于用in+String 查询
     */
    public static String converToString(String[] ig) {
        String str = "";
        if (ig != null && ig.length > 0) {
            for (int i = 0; i < ig.length; i++) {
                str += ig[i] + ",";
            }
        }
        str = str.substring(0, str.length() - 1);
        return str;
    }

    /**
     * @Description:把list转换为一个用逗号分隔的字符串
     */
    public static String listToString(List list) {
        StringBuilder sb = new StringBuilder();
        if (list != null && list.size() > 0) {
            for (int i = 0; i < list.size(); i++) {
                if (i < list.size() - 1) {
                    sb.append(list.get(i) + ",");
                } else {
                    sb.append(list.get(i));
                }
            }
        }
        return sb.toString();
    }

    public static int BinSearch(Integer[] data, Integer key) {
        int low = 0;
        int high = data.length - 1;
        int mid = 0;
        if (data[low] == key) {
            return low;
        }
        if (data[high] == key) {
            return high;
        }
        while (low <= high) {
            mid = (low + high) / 2;
            if (data[mid] == key) {
                return mid;
            }
            if (data[mid] > key) {
                high = mid - 1;
            } else {
                low = mid + 1;
            }
        }
        if (low > high) {
            return -1;
        }
        return 0;
    }

    public static List<Long> intListToLong(List<Integer> list) {
        if (CollectionUtils.isEmpty(list)) {
            return Collections.EMPTY_LIST;
        }
        List<Long> result = Lists.newArrayList();
        for (Integer one : list) {
            result.add(one.longValue());
        }
        return result;
    }

    public static List<Integer> longListToInt(List<Long> list) {
        if (CollectionUtils.isEmpty(list)) {
            return Collections.EMPTY_LIST;
        }
        List<Integer> result = Lists.newArrayList();
        for (Long one : list) {
            result.add(one.intValue());
        }
        return result;
    }

    public static void main(String[] args) {
        Integer[] data = {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
        System.out.println(BinSearch(data, 3));
        System.out.print(1 << 8);
    }
}
